# SEMIDV
SEMIDV is a semiconductor device simulator that solves finite-difference 2D Poisson-Drift-Diffusion equations with quantum effects.

## Installation

Install SEMIDV using pip:

```bash
pip install semidv
```

## Usage

```python
import semidv
```

For more details, please read the SEMIDV User Manual.

## Contributing

Pull requests are welcome. For major changes, please open an issue first
to discuss what you would like to change.

Please make sure to update tests as appropriate.

Clone the repository:

git clone https://github.com/chientingtung/SEMIDV.git

## License

This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Contact

GitHub: github.com/chientingtung/SEMIDV

Email: cttung@berkeley.edu
